@@ -16,7 +16,7 @@ class KTwoFingerSwipeTest : public QObject
 {
     Q_OBJECT
 
-    QTouchDevice *mDev = nullptr;
+    QPointingDevice *mDev = nullptr;
 
     QMainWindow mMainWindow;
     QWidget mWidget;
@@ -94,6 +94,14 @@ private:
     }
 
 private Q_SLOTS:
+    void cleanupTestCase()
+    {
+        delete mSpyTapFinished;
+        delete mSpyTapCanceled;
+        delete mSpyTapUpdated;
+        delete mSpyTapStarted;
+    }
+
     void initTestCase()
     {
         mDev = QTest::createTouchDevice();
