@@ -41,7 +41,7 @@ public:
 
     QFont font;
     KCharSelectItemModel *model = nullptr;
-    QVector<uint> chars;
+    QList<uint> chars;
     uint chr = 0;
 
     void resizeCells();
@@ -104,7 +104,7 @@ public:
     void linkClicked(QUrl url);
 };
 
-Q_DECLARE_TYPEINFO(KCharSelectPrivate::HistoryItem, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KCharSelectPrivate::HistoryItem, Q_RELOCATABLE_TYPE);
 
 /******************************************************************/
 /* Class: KCharSelectTable                                        */
@@ -164,7 +164,7 @@ QFont KCharSelectTable::font() const
     return d->font;
 }
 
-QVector<uint> KCharSelectTable::displayedChars() const
+QList<uint> KCharSelectTable::displayedChars() const
 {
     return d->chars;
 }
@@ -177,7 +177,7 @@ void KCharSelectTable::setChar(uint c)
     }
 }
 
-void KCharSelectTable::setContents(const QVector<uint> &chars)
+void KCharSelectTable::setContents(const QList<uint> &chars)
 {
     d->chars = chars;
 
@@ -213,7 +213,7 @@ void KCharSelectTablePrivate::slotSelectionChanged(const QItemSelection &selecte
         return;
     }
     QVariant temp = model->data(selected.indexes().at(0), KCharSelectItemModel::CharacterRole);
-    if (temp.type() != QVariant::UInt) {
+    if (temp.userType() != QMetaType::UInt) {
         return;
     }
     uint c = temp.toUInt();
@@ -258,9 +258,9 @@ void KCharSelectTablePrivate::resizeCells()
     // fontMetrics.maxWidth() doesn't help because of font fallbacks
     // (testcase: Malayalam characters)
     int maxCharWidth = 0;
-    const QVector<uint> chars = model->chars();
+    const QList<uint> chars = model->chars();
     for (int i = 0; i < chars.size(); ++i) {
-        uint thisChar = chars.at(i);
+        char32_t thisChar = chars.at(i);
         if (s_data()->isPrint(thisChar)) {
             maxCharWidth = qMax(maxCharWidth, fontMetrics.boundingRect(QString::fromUcs4(&thisChar, 1)).width());
         }
@@ -472,11 +472,11 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     d->sectionCombo->addItems(sectionList);
     d->blockCombo->setMinimumWidth(QFontMetrics(QWidget::font()).averageCharWidth() * 25);
 
-    connect(d->sectionCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, [this](int index) {
+    connect(d->sectionCombo, &QComboBox::currentIndexChanged, this, [this](int index) {
         d->sectionSelected(index);
     });
 
-    connect(d->blockCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, [this](int index) {
+    connect(d->blockCombo, &QComboBox::currentIndexChanged, this, [this](int index) {
         d->blockSelected(index);
     });
 
@@ -627,7 +627,7 @@ QList<QChar> KCharSelect::displayedChars() const
     return result;
 }
 
-QVector<uint> KCharSelect::displayedCodePoints() const
+QList<uint> KCharSelect::displayedCodePoints() const
 {
     return d->charTable->displayedChars();
 }
@@ -803,10 +803,10 @@ void KCharSelectPrivate::slotUpdateUnicode(uint c)
     }
     const QStringList aliases = s_data()->aliases(c);
     const QStringList notes = s_data()->notes(c);
-    const QVector<uint> seeAlso = s_data()->seeAlso(c);
+    const QList<uint> seeAlso = s_data()->seeAlso(c);
     const QStringList equivalents = s_data()->equivalents(c);
     const QStringList approxEquivalents = s_data()->approximateEquivalents(c);
-    const QVector<uint> decomposition = s_data()->decomposition(c);
+    const QList<uint> decomposition = s_data()->decomposition(c);
     if (!(aliases.isEmpty() && notes.isEmpty() && seeAlso.isEmpty() && equivalents.isEmpty() && approxEquivalents.isEmpty() && decomposition.isEmpty())) {
         html += QLatin1String("<p><b>") + tr("Annotations and Cross References") + QLatin1String("</b></p>");
     }
@@ -926,7 +926,7 @@ void KCharSelectPrivate::slotUpdateUnicode(uint c)
     html += tr("Block: ") + s_data()->block(c) + QLatin1String("<br>");
     html += tr("Unicode category: ") + s_data()->categoryText(s_data()->category(c)) + QLatin1String("</p>");
 
-    const QByteArray utf8 = QString::fromUcs4(&c, 1).toUtf8();
+    const QByteArray utf8 = QString::fromUcs4(reinterpret_cast<char32_t *>(&c), 1).toUtf8();
 
     html += QLatin1String("<p><b>") + tr("Various Useful Representations") + QLatin1String("</b><br>");
     html += tr("UTF-8:");
@@ -979,11 +979,11 @@ QString KCharSelectPrivate::createLinks(QString s)
 void KCharSelectPrivate::sectionSelected(int index)
 {
     blockCombo->clear();
-    QVector<uint> chars;
-    const QVector<int> blocks = s_data()->sectionContents(index);
+    QList<uint> chars;
+    const QList<int> blocks = s_data()->sectionContents(index);
     for (int block : blocks) {
         if (!allPlanesEnabled) {
-            const QVector<uint> contents = s_data()->blockContents(block);
+            const QList<uint> contents = s_data()->blockContents(block);
             if (!contents.isEmpty() && QChar::requiresSurrogates(contents.at(0))) {
                 continue;
             }
@@ -1016,7 +1016,7 @@ void KCharSelectPrivate::blockSelected(int index)
         // the selected block already contains the selected character
         return;
     }
-    const QVector<uint> contents = s_data()->blockContents(block);
+    const QList<uint> contents = s_data()->blockContents(block);
     if (sectionCombo->currentIndex() > 0) {
         charTable->setContents(contents);
     }
@@ -1055,7 +1055,7 @@ void KCharSelectPrivate::search()
         return;
     }
     searchMode = true;
-    QVector<uint> contents = s_data()->find(searchLine->text());
+    QList<uint> contents = s_data()->find(searchLine->text());
     if (!allPlanesEnabled) {
         contents.erase(std::remove_if(contents.begin(), contents.end(), QChar::requiresSurrogates), contents.end());
     }
@@ -1093,7 +1093,7 @@ QVariant KCharSelectItemModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    uint c = m_chars[pos];
+    char32_t c = m_chars[pos];
     if (role == Qt::ToolTipRole) {
         QString result = s_data()->display(c, m_font) + QLatin1String("<br />") + s_data()->name(c).toHtmlEscaped() + QLatin1String("<br />")
             + tr("Unicode code point:") + QLatin1Char(' ') + s_data()->formatCode(c) + QLatin1String("<br />") + tr("In decimal", "Character")
